
Scripts
-----------------

This section describes some of the various scripts that are distributed with
Pulsar.

.. include:: scripts/pulsar.rst

.. include:: scripts/pulsar_main.rst
.. include:: scripts/pulsar_config_windows.rst
.. include:: scripts/pulsar_config.rst
.. include:: scripts/pulsar_check.rst